@@ -21,7 +21,8 @@ class AmountLicensingCollabModel(Base):
         ForeignKey('licensing_collab.id'),
         nullable=False,
     )
-    value = Column(DECIMAL(13, 2), nullable=False)
+    deal_value = Column(DECIMAL(13, 2), nullable=False)
+    currency = Column(String(10), nullable=False)
     type = Column(String(50), nullable=False)
     updated_at = Column(
         DateTime,
