@@ -5,6 +5,7 @@ from marshmallow import (
     pre_load,
     ValidationError,
 )
+from ...utils.utils import pre_load_date_fields
 
 
 class CompanySECFilingResourceSchema(Schema):
@@ -18,6 +19,7 @@ class CompanySECFilingResourceSchema(Schema):
     sec_filing_date = fields.String()
     sec_accession_number = fields.String()
     sec_index_url = fields.String()
+    sec_url = fields.String()
     document_group = fields.String(allow_none=True)
     section_name = fields.String(allow_none=True)
     extraction_method = fields.String(allow_none=True)
@@ -26,7 +28,7 @@ class CompanySECFilingResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def pre_load(self, in_data):
+    def check_company_fields(self, in_data):
         if self._get_number_of_company_fields(in_data) > 1:
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id, not both')
@@ -40,3 +42,14 @@ class CompanySECFilingResourceSchema(Schema):
             if in_data['company_ous_id'] is not None:
                 result += 1
         return result
+
+    @pre_load
+    def convert_string_to_datetime(self, in_data):
+        date_fields = ['sec_filing_date']
+
+        in_data = pre_load_date_fields(
+            in_data,
+            date_fields,
+            date_format='%Y%m%d%H%M%S',
+        )
+        return in_data
