@@ -39,6 +39,8 @@ class CompanyScientificLinkModel(Base):
     outbound_ref_count = Column(Integer, nullable=True)
     orig_file_url = Column(String(255), nullable=True)
     best_oa_location = Column(String(255), nullable=True)
+    method = Column(String(128), nullable=True)
+    verification = Column(String(128), nullable=True)
     is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
