@@ -22,6 +22,8 @@ class ConditionNormModel(Base):
     )
     condition_norm_cui = Column(String(128), nullable=False, index=True)
     condition_norm_cui_name = Column(String(191), nullable=False, index=True)
+    condition_norm_cui_broader = Column(String(128), nullable=False, index=True)
+    condition_norm_cui_name_broader = Column(String(191), nullable=False, index=True)
     condition_norm_name = Column(String(191), nullable=False, index=True)
     updated_at = Column(
         DateTime,
